from eventstoredb.persistent_subscriptions.delete.grpc import (
    create_delete_request_options,
)
from eventstoredb.persistent_subscriptions.delete.types import (
    DeletePersistentSubscriptionOptions,
)
